// MassBuilderSaveTool
// Copyright (C) 2021 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include "MassBuilderManager.h"

#include <Corrade/Containers/ScopeGuard.h>
#include <Corrade/Utility/Directory.h>
#include <Corrade/Utility/Unicode.h>

#include <shlobj.h>
#include <wtsapi32.h>

using namespace Corrade;

MassBuilderManager::MassBuilderManager() {
    _ready = findSaveDirectory();
}

auto MassBuilderManager::ready() const -> bool {
    return _ready;
}

auto MassBuilderManager::lastError() -> std::string const& {
    return _lastError;
}

auto MassBuilderManager::saveDirectory() -> std::string const& {
    return _saveDirectory;
}

void MassBuilderManager::checkGameState() {
    WTS_PROCESS_INFOW* process_infos = nullptr;
    unsigned long process_count = 0;

    if(WTSEnumerateProcessesW(WTS_CURRENT_SERVER_HANDLE, 0, 1, &process_infos, &process_count)) {
        Containers::ScopeGuard guard{process_infos, WTSFreeMemory};

        for(unsigned long i = 0; i < process_count; ++i) {
            if(std::wcscmp(process_infos[i].pProcessName, L"MASS_Builder-Win64-Shipping.exe") == 0) {
                _gameState = GameState::Running;
                break;
            }
            else {
                _gameState = GameState::NotRunning;
            }
        }
    }
    else {
        _gameState = GameState::Unknown;
    }
}

auto MassBuilderManager::gameState() -> GameState {
    return _gameState;
}

auto MassBuilderManager::findSaveDirectory() -> bool {
    wchar_t* localappdata_path;
    Containers::ScopeGuard guard{localappdata_path, CoTaskMemFree};
    if(SHGetKnownFolderPath(FOLDERID_LocalAppData, KF_FLAG_NO_APPCONTAINER_REDIRECTION, nullptr, &localappdata_path) != S_OK)
    {
        _lastError = "SHGetKnownFolderPath() failed in MassBuilderManager::findSaveDirectory()";
        return false;
    }

    _saveDirectory = Utility::Directory::join(Utility::Directory::fromNativeSeparators(Utility::Unicode::narrow(localappdata_path)), "MASS_Builder");

    if(!Utility::Directory::exists(_saveDirectory)) {
        _lastError = _saveDirectory + " wasn't found.";
        return false;
    }

    return true;
}
